oumi.models.experimental.cambrian.model.language\_model
=======================================================
.. py:module:: oumi.models.experimental.cambrian.model.language_model

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   oumi.models.experimental.cambrian.model.language_model.phi3
